#!/usr/bin/python
#
# GCompris - wordlist-json-2html.py
#
# Copyright (C) 2018 Johnny Jazeix <jazeix@gmail.com>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, see <https://www.gnu.org/licenses/>.

import json

wordsFile="../src/activities/lang/resource/words.json"

with open(wordsFile) as data_file:
    try:
        data = json.load(data_file)
        print("Processing OK " + wordsFile)
    except ValueError as e:
        print(dir(e))
        print("Processing KO " + wordsFile)
        print("Parser error: {0}".format(e.message))

header="""<html dir=\"ltr\" lang=\"fr\">
<head>
  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">
</head>
<body>
  <a name=\"words_by_section\" href=\"words_by_section.html\"/>Same list of words by section</a>
  <p></p>
  <a name=\"empty json\" href=\"words.json\"/>Empty json data file ready to be translated</a>
  <hr>
"""

footer= """
</body>
</html>"""

orderedData = {}

with open("words_by_section.html", "w") as section_file:
    section_file.write("""<html dir=\"ltr\" lang=\"fr\">

<head>
  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">
</head>
<body>

""")
    for chapter in data:
        for lesson in chapter["content"]:
            lessonName = lesson["name"];
            if lessonName == "otherLesson":
                lessonName = "other"
            section_file.write("  <h1>" + lessonName + "</h1>\n")
            for content in lesson["content"]:
                # store the info for words.html
                orderedData[content["description"]] = {
                    "image": content["image"],
                    "section": lessonName
                    };
                # write in the file
                section_file.write("""      <a name=\""""+content["description"]+"""\" href=\"lang/""" + content["image"] + """\"><img src=\"lang/"""+content["image"] + """\"/></a>
      <p>"""+content["description"]+"""</p>
      <hr/>
""")
    section_file.write(footer)

with open("words.html", "w") as words_file:
    words_file.write(header)
    for key in sorted(orderedData):
        words_file.write("  <a name=\""+key+"\" href=\"lang/"+orderedData[key]["image"]+"\"><img src=\"lang/"+orderedData[key]["image"]+"\"/></a><p>"+key+" ("+orderedData[key]["section"]+")</p><hr/>\n")
    words_file.write(footer)



#!/usr/bin/python
#
# GCompris - datasetToPo.py
#
# Copyright (C) 2015 Bruno Coudoin <bruno.coudoin@gcompris.net>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, see <https://www.gnu.org/licenses/>.

import sys
import json
import os
import datetime

if(len(sys.argv) < 2):
    print "Usage: dataSetToPo.py dataset.json [content-fr.json]"
    print "  The optional argument is used to backport manually created json"
    sys.exit(1)

def loadManualFile(manual):
    json_data = open(manual)
    manualData = json.load(json_data)
    json_data.close()
    return manualData
    
def getManualTranslation(manualData, key):
    if not manualData:
        return ""
    key = key.split("/")[-1]
    try:
        return manualData[key]
    except:
        return ""

manualData = None
if(len(sys.argv) == 3):
    manualData = loadManualFile(sys.argv[2])


dataset = sys.argv[1]
json_data = open(dataset)
data = json.load(json_data)
json_data.close()

# Get last modification time of data set
modtime = os.path.getmtime(dataset)
modtime_utc = datetime.datetime.utcfromtimestamp(modtime)
modtime_utc_string = modtime_utc.strftime('%Y-%m-%d %H:%M') + '+0000'

# Header
print 'msgid ""'
print 'msgstr ""'
print '"Project-Id-Version: gcompris_qt\\n"'
print '"POT-Creation-Date: ' + modtime_utc_string + '\\n"'
print '"MIME-Version: 1.0\\n"'
print '"Content-Type: text/plain; charset=UTF-8\\n"'
print '"Content-Transfer-Encoding: 8bit\\n"'
print ''

for chapter in data:
    for lesson in chapter['content']:
        for word in lesson['content']:
            print "#. " + chapter['name'] + \
                " / " + lesson['name'] + \
                " / " + word['description'] + \
                ": https://gcompris.net/incoming/lang/words.html#" + \
                word['image'].split('/')[-1].split(".")[0]
            print "#: " + "https://gcompris.net/incoming/lang/words.html#" + \
                word['image'].split('/')[-1].split(".")[0]
            print 'msgctxt "LangWords|"'
            print 'msgid "' + word['description'] + '"'
            print 'msgstr "' + getManualTranslation(manualData, word['voice']).encode('utf-8') + '"'
            print ""



#!/usr/bin/python
#
# GCompris - download-assets.py
#
# Copyright (C) 2016-2018 Johnny Jazeix <jazeix@gmail.com>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, see <https://www.gnu.org/licenses/>.
import urllib.request
import shutil
import sys

# see https://stackoverflow.com/questions/7243750/download-file-from-web-in-python-3/7244263#7244263
def download_file(from_url, output_dir):
    file_name = output_dir + "/" + from_url.split('/')[-1]
    with urllib.request.urlopen(from_url) as response, open(file_name, 'wb') as out_file:
        shutil.copyfileobj(response, out_file)

# argv[0]: program name
# argv[1]: assets to download (words, full for full rccs, locale to get correpsonding locale voices)
# argv[2]: audio format (ogg, mp3, aac)
# argv[3]: output directory (rcc directory)
if len(sys.argv) != 4:
    print("Usage: download-assets.py \"words,full,en,fr,pt_BR\" ogg/mp3/aac outputFolder")
    sys.exit(0)

"""Download the voices and words assets depending on the wanted audio format
"""

DOWNLOAD_PATH = "http://gcompris.net/data2/"
AUDIO_FORMAT = sys.argv[2]
OUTPUT_FOLDER = sys.argv[3]+"/data2/"

ALL_LANGUAGES = [x.strip() for x in sys.argv[1].split(",") if len(x)]
DOWNLOAD_WORDS = "words" in ALL_LANGUAGES
DOWNLOAD_FULL = "full" in ALL_LANGUAGES
if DOWNLOAD_WORDS:
    ALL_LANGUAGES.remove("words")
    download_file(DOWNLOAD_PATH+"words/words.rcc", OUTPUT_FOLDER+"words/")

if DOWNLOAD_FULL:
    ALL_LANGUAGES.remove("full")
    download_file(DOWNLOAD_PATH+"full-"+AUDIO_FORMAT+".rcc", OUTPUT_FOLDER)

for lang in ALL_LANGUAGES:
    lang_url = DOWNLOAD_PATH+"voices-"+AUDIO_FORMAT+"/voices-"+lang+".rcc"
    download_file(lang_url, OUTPUT_FOLDER+"voices-"+AUDIO_FORMAT+"/")



#!/usr/bin/python2
#
# GCompris - mergePo.py
#
# Copyright (C) 2017 Johnny Jazeix <jazeix@gmail.com>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, see <https://www.gnu.org/licenses/>.

# Using polib.py from https://bitbucket.org/izi/polib/wiki/Home

# Usage : python2 mergePo.py qt.po gtk.po
# Find in the first argument po file the translated lines of the gtk po file
# (if existing) and replace the translation for the po file.
# For those not found, no translation is provided.

# something like: python2 mergePo.py gcompris_fi.po fi.po && sed '/^#|/ d' < gcompris_fi.po > qtgl.po && mv qtgl.po gcompris_fi.po

import sys
import polib

if len(sys.argv) < 3:
    print('Usage : python mergePo.py gcompris_qt.po gcompris_gtk.po.'
          ' Output will be in the input file!')
    sys.exit(1)

# load an existing po file
po = polib.pofile(sys.argv[1])
poGtk = polib.pofile(sys.argv[2])

print(po.percent_translated())

# First remove all fuzzy strings
for entry in po.fuzzy_entries():
    entry.msgstr = ''
    if entry.msgid_plural:
        entry.msgstr_plural['0'] = ''
    if entry.msgid_plural and '1' in entry.msgstr_plural:
        entry.msgstr_plural['1'] = ''
    if entry.msgid_plural and '2' in entry.msgstr_plural:
        entry.msgstr_plural['2'] = ''
    entry.flags.remove('fuzzy')
    po.save()

# uncomment to create a new po
#for entry in po:
#    if entry.msgstr != "":
#        entry.msgstr = "";

#print(po.percent_translated())

# Then replace in the output all the good strings
for entry in po:
    if entry.msgstr != "":
        continue

    for entryGtk in poGtk:
        if entry.msgid.encode('utf-8') == entryGtk.msgid.encode('utf-8') and entryGtk.msgstr != "":
            entry.msgstr = entryGtk.msgstr

po.save()

print(po.percent_translated())



#!/usr/bin/python
#
# GCompris - convertPo.py
#
# Copyright (C) 2015 Bruno Coudoin <bruno.coudoin@gcompris.net>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, see <https://www.gnu.org/licenses/>.

# Using polib.py from https://bitbucket.org/izi/polib/wiki/Home

# Usage : python convertPo.py input1.po input2.ts output.ts
# Find in the first argument po file the translated lines of the ts file
# (if existing) and replace the translation for the ts file.
# For those not found, no translation is provided.

import sys
import xml.etree.ElementTree as ET
import polib

if len(sys.argv) < 4:
    print('Usage : python convertPo.py gcompris_gtk.po gcompris_qt_template.ts $LOCALE.'
          ' Output will be gcompris_$LOCALE.ts ($LOCALE is fr_FR for example).')
    sys.exit(1)

# load an existing po file
po = polib.pofile(sys.argv[1])
tree = ET.parse(sys.argv[2])
root = tree.getroot()

# Change the language in the xml file
root.set('language', sys.argv[3])

for messages in root.iter('message'):
    original = messages.find('source').text
    if original is not None:
        for entry in po:
            if entry.msgid.encode('utf-8') == original.encode('utf-8') and \
                    'type' in messages.find('translation').attrib and \
                    messages.find('translation').attrib['type'] == 'unfinished':
                messages.find('translation').text = entry.msgstr
                try:
                    messages.find('translation').attrib.pop('type')
                except:
                    pass
                break

with open('gcompris_' + sys.argv[3] + '.ts', 'wb') as f:
    f.write('<?xml version="1.0" encoding="utf-8" ?>\n<!DOCTYPE TS>\n'.encode('utf-8'))
    tree.write(f, 'utf-8')
# tree.write('gcompris_' + sys.argv[3] + '.ts', 'utf-8');



#!/usr/bin/python
#
# GCompris - validate-json.py
#
# Copyright (C) 2015 Bruno Coudoin <bruno.coudoin@gcompris.net>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, see <https://www.gnu.org/licenses/>.
import json
import sys

if len(sys.argv) != 2:
    print "Usage: validate-json.py json_file"
    sys.exit(1)

inf=sys.argv[1]

with open(inf) as data_file:
    try:
        data = json.load(data_file)
        print "Processing OK " + inf
    except ValueError as e:
        print dir(e)
        print "Processing KO " + inf
        print "Parser error: {0}".format(e.message)




#!/usr/bin/python
#
# GCompris - gencode.py
#
# Copyright (C) 2016 Bruno Coudoin <bruno.coudoin@gcompris.net>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, see <https://www.gnu.org/licenses/>.

# Generate code for today
import random
from datetime import datetime

user = int(random.random() * 0xFFFF)
date = (datetime.now().year << 4) | datetime.now().month
crc = user ^ date ^ 0xCECA
print "%04X-%04X-%04X" %(user, date, crc)




#!/usr/bin/python
#
# GCompris - createAppicon.py
#
# Copyright (C) 2015 Bruno Coudoin <bruno.coudoin@gcompris.net>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, see <https://www.gnu.org/licenses/>.

import json
import subprocess
import sys
import os

if len(sys.argv) < 3:
    print 'Usage: createAppicon.py Images.xcassets/AppIcon.appiconset icon_no_corner.svg'
    sys.exit(1)

outdir = sys.argv[1]
image_source = sys.argv[2]

try:
    os.makedirs(outdir)
except:
    pass

images = [
    [ 29, "iphone", 1 ],
    [ 29, "iphone", 2 ],
    [ 29, "iphone", 3 ],
    [ 40, "iphone", 2 ],
    [ 40, "iphone", 3 ],
    [ 57, "iphone", 1 ],
    [ 57, "iphone", 2 ],
    [ 60, "iphone", 2 ],
    [ 60, "iphone", 3 ],
    [ 29, "ipad", 1 ],
    [ 29, "ipad", 2 ],
    [ 40, "ipad", 1 ],
    [ 40, "ipad", 2 ],
    [ 50, "ipad", 1 ],
    [ 50, "ipad", 2 ],
    [ 72, "ipad", 1 ],
    [ 72, "ipad", 2 ],
    [ 76, "ipad", 1 ],
    [ 76, "ipad", 2 ],
    [ 83.5, "ipad", 2 ]
]

content = {
    "images": [],
    "info": {
        "version": 1,
        "author": "GCompris"
    }
}

for image in images:
    size = image[0]
    idiom = image[1]
    scale = image[2]
    scalestr = str(scale) + 'x'
    filesizestr = str(int(size * scale)) + 'x' + str(int(size * scale))
    sizestr = str(size) + 'x' + str(size)
    filename = "appicon-" + filesizestr + ".png"
    content['images'].append(
        {
            "size": sizestr,
            "idiom": idiom,
            "filename": filename,
            "scale": scalestr
        }
    )

    subprocess.call(["inkscape", image_source,
                     "-e", outdir + '/' + filename,
                     "-w", str(int(size * scale)),
                     "-h", str(int(size * scale))])

with open(outdir + '/Contents.json', 'w') as f:
    f.write(json.dumps(content, sort_keys=True,
                       indent=4, separators=(',', ': ')))



#!/usr/bin/python
#
# GCompris - l10n-fetch-po-files.py
#
# Copyright (C) 2015 Trijita org <jktjkt@trojita.org>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, see <https://www.gnu.org/licenses/>.
import os
import re
import subprocess

# Copied from Trojita
"""Fetch the .po files from KDE's SVN for GCompris

Run me from GCompris's top-level directory.
"""


SVN_PATH = "svn://anonsvn.kde.org/home/kde/branches/stable/l10n-kf5/"
SOURCE_PO_PATH = "/messages/extragear-edu/gcompris_qt.po"
OUTPUT_PO_PATH = "./po/"
OUTPUT_PO_PATTERN = "gcompris_%s.po"

fixer = re.compile(r'^#~\| ', re.MULTILINE)
re_empty_msgid = re.compile('^msgid ""$', re.MULTILINE)
re_empty_line = re.compile('^$', re.MULTILINE)
re_has_qt_contexts = re.compile('X-Qt-Contexts: true\\n')

if not os.path.exists(OUTPUT_PO_PATH):
    os.mkdir(OUTPUT_PO_PATH)

all_languages = subprocess.check_output(['svn', 'cat', SVN_PATH + 'subdirs'],
                                       stderr=subprocess.STDOUT)

all_languages = [x.strip() for x in all_languages.split("\n") if len(x)]
all_languages.remove("x-test")
for lang in all_languages:
    try:
        raw_data = subprocess.check_output(['svn', 'cat', SVN_PATH + lang + SOURCE_PO_PATH],
                                          stderr=subprocess.PIPE)
        (transformed, subs) = fixer.subn('# ~| ', raw_data)
        pos1 = re_empty_msgid.search(transformed).start()
        pos2 = re_empty_line.search(transformed).start()
        if re_has_qt_contexts.search(transformed, pos1, pos2) is None:
            transformed = transformed[:pos2] + \
                    '"X-Qt-Contexts: true\\n"\n' + \
                    transformed[pos2:]
            subs = subs + 1
        if (subs > 0):
            print "Fetched %s (and performed %d cleanups)" % (lang, subs)
        else:
            print "Fetched %s" % lang
        file(OUTPUT_PO_PATH + OUTPUT_PO_PATTERN % lang, "wb").write(transformed)
    except subprocess.CalledProcessError:
        print "No data for %s" % lang

# Inform qmake about the updated file list
#os.utime("CMakeLists.txt", None)

